@@ -2,14 +2,13 @@ __title__ = 'statcord.py-beta'
 __author__ = 'statcord.com'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2020, statcord.com'
-__version__ = '3.0.3'
+__version__ = '3.1.0'
 
 name = "statcord"
 
-from collections import namedtuple # noqa E402
-from .client import Client # noqa E402
-from .exceptions import * # noqa E402
+from collections import namedtuple
+from .client import Client
+from .exceptions import *
 
 VersionInfo = namedtuple('VersionInfo', 'major minor micro releaselevel serial')
-
-version_info = VersionInfo(major=3, minor=0, micro=3, releaselevel='final', serial=0)
+version_info = VersionInfo(major=3, minor=1, micro=0, releaselevel='final', serial=0)
